@@ -31,6 +31,8 @@ if __name__ == "__main__":
 
 	logging.basicConfig(level=logging.DEBUG, filename=constants._user_logpath_)
 	_moduleLogger.info("quicknote %s-%s" % (constants.__version__, constants.__build__))
+	_moduleLogger.info("OS: %s" % (os.uname()[0], ))
+	_moduleLogger.info("Kernel: %s (%s) for %s" % os.uname()[2:])
+	_moduleLogger.info("Hostname: %s" % os.uname()[1])
 
-	app = quicknote_gtk.QuicknoteProgram()
-	app.main()
+	quicknote_gtk.run_quicknote()
